Overview: module code — src documentation

# All modules for which code is available

- synthetic_aia_mia.aia

- synthetic_aia_mia.aia.soft

- synthetic_aia_mia.fetch_data

- synthetic_aia_mia.fetch_data.adult
- synthetic_aia_mia.fetch_data.split
- synthetic_aia_mia.fetch_data.utk

- synthetic_aia_mia.generator

- synthetic_aia_mia.generator.adult
- synthetic_aia_mia.generator.example

- synthetic_aia_mia.metrics
- synthetic_aia_mia.mia

- synthetic_aia_mia.mia.ml

- synthetic_aia_mia.predictor.adult
- synthetic_aia_mia.predictor.utk